import { useRouter } from 'vue-router';

/**
 * Navigate to a VM without using URL parameters
 * @param {string} vmId - The ID of the VM to navigate to
 * @param {import('vue-router').Router} router - Vue Router instance
 */
export function navigateToVM(vmId, router) {
  // Save the VM ID to localStorage
  localStorage.setItem('selectedVMId', vmId);
  
  // Navigate to the VMs page
  router.push('/vms');
}

/**
 * Navigate to a node without using URL parameters
 * @param {string} nodeId - The ID of the node to navigate to
 * @param {import('vue-router').Router} router - Vue Router instance
 */
export function navigateToNode(nodeId, router) {
  // Save the node ID to localStorage
  localStorage.setItem('selectedNodeId', nodeId);
  
  // Navigate to the Nodes page
  router.push('/nodes');
}

/**
 * Clear the selected VM and return to the default VM page view
 * @param {import('vue-router').Router} router - Vue Router instance
 */
export function clearSelectedVM(router) {
  // Clear from localStorage
  localStorage.removeItem('selectedVMId');
  
  // Navigate to the VMs page without query parameters
  router.push('/vms');
} 