/**
 * Selects a VM and saves the selection to localStorage
 * @param {string} vmId - The ID of the VM to select
 * @param {import('vue-router').Router} router - Vue Router instance (optional)
 */
export function selectVM(vmId, router = null) {
  // Save to localStorage
  localStorage.setItem('selectedVMId', vmId);
  
  // Optionally update URL if router is provided
  if (router) {
    router.push({ 
      path: '/vms',
      query: { vm: vmId }
    });
  }
}

/**
 * Gets the currently selected VM from localStorage
 * @returns {string|null} The selected VM ID or null if none is selected
 */
export function getSelectedVM() {
  return localStorage.getItem('selectedVMId');
}

/**
 * Clears the selected VM from localStorage
 */
export function clearSelectedVM() {
  localStorage.removeItem('selectedVMId');
} 